@@ -309,7 +309,10 @@ class PulsedMediaClient(SeedboxClient):
         if 'addTorrentSuccess' in r.content:
             return
         elif 'addTorrentFailed' in r.content:
-            raise InvalidTorrent(magnet_link)
+            if data in params:
+                raise InvalidTorrent(params['data']['url'])
+            else:
+                raise InvalidTorrent(params['files']['torrent_file'][0])
         else:
             assert 0, (r.status_code, r.content)
 
